@@ -12,6 +12,7 @@ use bytes::{Buf, BufMut, Bytes, BytesMut};
 pub const VP8_HEADER_SIZE: isize = 1;
 
 /// Vp8Payloader payloads VP8 packets
+#[derive(Debug, Copy, Clone)]
 pub struct Vp8Payloader;
 
 impl Payloader for Vp8Payloader {
@@ -71,10 +72,14 @@ impl Payloader for Vp8Payloader {
 
         Ok(payloads)
     }
+
+    fn clone_to(&self) -> Box<dyn Payloader + Send + Sync> {
+        Box::new(*self)
+    }
 }
 
 /// Vp8Packet represents the VP8 header that is stored in the payload of an RTP Packet
-#[derive(Debug, Default)]
+#[derive(PartialEq, Debug, Default, Clone)]
 pub struct Vp8Packet {
     // Required Header
     pub x: u8,   /* extended controlbits present */
